@@ -2,8 +2,11 @@ from .lpp_type import LppType
 
 
 class LppData(object):
-    """
-    A LPP data object.
+    """A LPP data object.
+
+    A LppData contains all information related to a single sensor
+    value, i.e. its type, value, and the channel for multiplexing
+    various sensor devices with values of the same type.
 
     Attributes:
         chn (int):      data channel number
@@ -12,7 +15,7 @@ class LppData(object):
     """
 
     def __init__(self, chn, type_, value):
-        """Create a LppData object with given attriubes."""
+        """Create a LppData object with given attributes."""
         self.channel = chn
         self.type = LppType.get_lpp_type(type_)
         if self.type is None:
@@ -44,6 +47,10 @@ class LppData(object):
         return 'LppData(channel = {}, type = {}, value = {})'.format(
                 self.channel, self.type.name, str(self.value))
 
+    def to_bytes(self):
+        """Explicit wrapper for MicroPython support."""
+        return self.__bytes__()
+
     @classmethod
     def from_bytes(class_object, buf):
         """Parse a given byte string and return a LppData object."""
